@@ -40,12 +40,14 @@ import cPickle as pickle
 from time import strftime
 
 #related third party imports
+import numpy as np
 from numpy import array,exp,cos,sin,arcsin,arccos,sqrt,size,mean,column_stack,cov,unique,hsplit,correlate,log,dot,power,squeeze,sort
 from scipy import stats
 
 import matplotlib
 matplotlib.use("Agg")
 from matplotlib import pyplot as plt
+import cbcBayesPlotSpinDisk as cbcdiskspin
 
 # Default font properties
 fig_width_pt = 246  # Get this from LaTeX using \showthe\columnwidth
@@ -86,10 +88,12 @@ __date__= git_version.date
 def email_notify(address,path):
     import smtplib
     import subprocess
+    import socket
+    import os
     address=address.split(',')
     SERVER="localhost"
     USER=os.environ['USER']
-    HOST=os.environ['HOSTNAME']
+    HOST=socket.getfqdn()
     FROM=USER+'@'+HOST
     SUBJECT="LALInference result is ready at "+HOST+"!"
     # Guess the web space path for the clusters
@@ -110,16 +114,15 @@ def email_notify(address,path):
     else:
         webpath=os.path.join(fslocation,'posplots.html')
         onweb=False
-
-    if 'atlas.aei.uni-hannover.de' in HOST:
+    if 'atlas' in HOST:
         url="https://atlas1.atlas.aei.uni-hannover.de/"
-    elif 'ligo.caltech.edu' in HOST:
+    elif 'cit' in HOST or 'caltech' in HOST:
         url="https://ldas-jobs.ligo.caltech.edu/"
-    elif 'ligo-wa.caltech.edu' in HOST:
+    elif 'ligo-wa' in HOST:
         url="https://ldas-jobs.ligo-wa.caltech.edu/"
-    elif 'ligo-la.caltech.edu' in HOST:
+    elif 'ligo-la' in HOST:
         url="https://ldas-jobs.ligo-la.caltech.edu/"
-    elif 'phys.uwm.edu' in HOST:
+    elif 'uwm' in HOST or 'nemo' in HOST:
         url="https://ldas-jobs.phys.uwm.edu/"
     elif 'phy.syr.edu' in HOST:
         url="https://sugar-jobs.phy.syr.edu/"
@@ -133,10 +136,10 @@ def email_notify(address,path):
     url=url+webpath
 
     TEXT="Hi "+USER+",\nYou have a new parameter estimation result on "+HOST+".\nYou can view the result at "+url+"\n"
-    message="From: %s\nTo: %s\nSubject: %s\n\n%s"%(FROM,', '.join(address),SUBJECT,TEXT)
-    server=smtplib.SMTP(SERVER)
-    server.sendmail(FROM,address,message)
-    server.quit()
+    cmd='echo "%s" | mail -s "%s" "%s"'%(TEXT,SUBJECT,', '.join(address))
+    proc = subprocess.Popen(cmd, stdout=subprocess.PIPE,stderr=subprocess.STDOUT, shell=True)
+    (out, err) = proc.communicate()
+    #print "program output %s error %s:"%(out,err)
 
 #Import content handler 
 from pylal.SimInspiralUtils import ExtractSimInspiralTableLIGOLWContentHandler
@@ -184,7 +187,7 @@ def multipleFileCB(opt, opt_str, value, parser):
     setattr(parser.values, opt.dest, args)
 
 def cbcBayesPostProc(
-                        outdir,data,oneDMenu,twoDGreedyMenu,GreedyRes,
+                        outdir,data,oneDMenus,twoDGreedyMenu,GreedyRes,
                         confidence_levels,twoDplots,
                         #misc. optional
                         injfile=None,eventnum=None,
@@ -275,9 +278,16 @@ def cbcBayesPostProc(
         commonResultsObj=peparser.parse(data[0])
         thefile=open(data[0],'r')
         votfile=thefile.read()
+    elif '.hdf' in data[0] or '.h5' in data[0]:
+        peparser = bppu.PEOutputParser('hdf5')
+        commonResultsObj = peparser.parse(data[0])
     else:
         peparser=bppu.PEOutputParser('common')
         commonResultsObj=peparser.parse(open(data[0],'r'),info=[header,None])
+        # check if Nest (through nest2post) has produced an header file with git and CL info. If yes copy in outdir
+        if os.path.isfile(data[0]+"_header.txt"):
+          import shutil
+          shutil.copy2(data[0]+"_header.txt", os.path.join(outdir,'nest_headers.txt'))
     
     #Extract f_ref from CRO if present.  This is needed to calculate orbital angular momentum
     #  when converting spin parameters.  Ideally this info will be provided in the
@@ -376,11 +386,11 @@ def cbcBayesPostProc(
             except KeyError:
                 print "Warning: No 'time' column!"
 
-    try:
-      pos.extend_posterior()
-    except:
-      pass
-
+    pos.extend_posterior()
+    # create list of names in oneDMenus dic
+    oneDMenu=[]
+    for i in oneDMenus.keys():
+      oneDMenu+=oneDMenus[i]
     #Perform necessary mappings
     functions = {'cos':cos,'sin':sin,'exp':exp,'log':log}
     for pos_name in oneDMenu:
@@ -414,6 +424,10 @@ def cbcBayesPostProc(
     max_pos,max_pos_co=pos.maxL
     print max_pos_co
 
+    # Save posterior samples
+    posfilename=os.path.join(outdir,'posterior_samples.dat')
+    pos.write_to_file(posfilename)
+    
     #==================================================================#
     #Create web page
     #==================================================================#
@@ -506,12 +520,21 @@ def cbcBayesPostProc(
     html_stats.write(str(pos))
     statfilename=os.path.join(outdir,"summary_statistics.dat")
     statout=open(statfilename,"w")
-    statout.write("\tmaP\tmaxL\tstdev\tmean\tmedian\tstacc\tinjection\tvalue\n")
+    statout.write("\tmaP\tmaxL\tKL\tstdev\tmean\tmedian\tstacc\tinjection\tvalue\n")
     
+    warned_about_kl = False
     for statname,statoned_pos in pos:
 
       statmax_pos,max_i=pos._posMaxL()
       statmaxL=statoned_pos.samples[max_i][0]
+      try:
+          statKL = statoned_pos.KL()
+      except ValueError:
+          if not warned_about_kl:
+              print("Unable to compute KL divergence")
+              warned_about_kl = True
+          statKL = None
+
       statmax_pos,max_j=pos._posMap()
       statmaxP=statoned_pos.samples[max_j][0]
       statmean=str(statoned_pos.mean)
@@ -520,7 +543,7 @@ def cbcBayesPostProc(
       statstacc=str(statoned_pos.stacc)
       statinjval=str(statoned_pos.injval)
       
-      statarray=[str(i) for i in [statname,statmaxP,statmaxL,statstdev,statmean,statmedian,statstacc,statinjval]]
+      statarray=[str(i) for i in [statname,statmaxP,statmaxL,statKL,statstdev,statmean,statmedian,statstacc,statinjval]]
       statout.write("\t".join(statarray))
       statout.write("\n")
       
@@ -572,48 +595,71 @@ def cbcBayesPostProc(
         os.makedirs(wfdir)
     try:
         wfpointer= bppu.plot_waveform(pos=pos,siminspiral=injfile,event=eventnum,path=wfdir)
-    except:
+    except  Exception,e:
         wfpointer = None
+        print "Could not create WF plot. The error was: %s\n"%str(e)
     wftd=html_wf.insert_td(row,'',label='Waveform',legend=legend)
     wfsection=html.add_section_to_element('Waveforms',wftd)
-    if wfpointer:
+    if wfpointer is not None:
       wfsection.write('<a href="Waveform/WF_DetFrame.png" target="_blank"><img src="Waveform/WF_DetFrame.png"/></a>')
     else:
+      print "Could not create WF plot.\n"
       wfsection.write("<b>No Waveform generated!</b>")
       
     wftd=html_wf.insert_td(row,'',label='PSDs',legend=legend)
     wfsection=html.add_section_to_element('PSDs',wftd)
-    psd_pointer=None
     if psd_files is not None:
       psd_files=list(psd_files.split(','))
       psddir=os.path.join(outdir,'PSDs')
       if not os.path.isdir(psddir):
         os.makedirs(psddir)
       try:
-        psd_pointer=bppu.plot_psd(psd_files,outpath=psddir)    
-      except:
-        psd_pointer=None
-    if psd_pointer:
-      wfsection.write('<a href="PSDs/PSD.png" target="_blank"><img src="PSDs/PSD.png"/></a>')
+        bppu.plot_psd(psd_files,outpath=psddir)
+        wfsection.write('<a href="PSDs/PSD.png" target="_blank"><img src="PSDs/PSD.png"/></a>')
+      except  Exception,e:
+        print "Could not create PSD plot. The error was: %s\n"%str(e)
+        wfsection.write("<b>PSD plotting failed</b>")
     else:
-      wfsection.write("<b>No PSD file found!</b>")
+        wfsection.write("<b>No PSD files provided</b>")
+
+    # Add plots for calibration estimates
+    if np.any(['spcal_amp' in param for param in pos.names]) or np.any(['spcal_phase' in param for param in pos.names]):
+      wftd=html_wf.insert_td(row,'',label='Calibration',legend=legend)
+      wfsection=html.add_section_to_element('Calibration',wftd)
+      bppu.plot_calibration_pos(pos, outpath=outdir)
+      wfsection.write('<a href="calibration.png" target="_blank"><img src="calibration.png"/></a>')
+     # if precessing spins do spin disk
+    allin=1.0
+    for i in ['a1','tilt_spin1','a2','tilt_spin2']:
+      if not i in pos.names:
+        allin*=0.0
+    if allin ==0.0:
+      pass
+    else:
+      wftd=html_wf.insert_td(row,'',label='DiskPlot',legend=legend)
+      wfsection=html.add_section_to_element('DiskPlot',wftd)
+      cbcdiskspin.make_disk_plot(pos, outpath=outdir)
+      wfsection.write('<a href="comp_spin_pos.png" target="_blank"><img src="comp_spin_pos.png"/></a>')
+
     #==================================================================#
     #1D posteriors
     #==================================================================#
+    onepdfdir=os.path.join(outdir,'1Dpdf')
+    if not os.path.isdir(onepdfdir):
+        os.makedirs(onepdfdir)
 
-    #Loop over each parameter and determine the contigious and greedy
-    #confidence levels and some statistics.
+    sampsdir=os.path.join(outdir,'1Dsamps')
+    if not os.path.isdir(sampsdir):
+        os.makedirs(sampsdir)
+    reses={}
+    
+    for i in oneDMenus.keys():
+      rss=bppu.make_1d_table(html,legend,i,pos,oneDMenus[i],noacf,GreedyRes,onepdfdir,sampsdir,savepdfs,greedy,analyticLikelihood,nDownsample)
+      reses.update(rss)
 
-    #Add section for 1D marginal PDFs and sample plots
-    tabid='onedmargtable'
-    html_ompdf=html.add_collapse_section('1D marginal posterior PDFs',legend=legend,innertable_id=tabid)
-    #Table matter
-    if not noacf:
-        html_ompdf_write= '<table id="%s"><tr><th>Histogram and Kernel Density Estimate</th><th>Samples used</th><th>Autocorrelation</th></tr>'%tabid
-    else:
-        html_ompdf_write= '<table id="%s"><tr><th>Histogram and Kernel Density Estimate</th><th>Samples used</th></tr>'%tabid
-
-#Add section for 1D confidence intervals
+    
+    
+    
     tabid='onedconftable'
     html_ogci=html.add_collapse_section('1D confidence intervals (greedy binning)',legend=legend,innertable_id=tabid)
     html_ogci_write='<table id="%s" border="1"><tr><th/>'%tabid
@@ -629,236 +675,86 @@ def cbcBayesPostProc(
         clasciiout+="Injection_Confidence_Interval"
     clasciiout+='\n'
     html_ogci_write+='</tr>'
-
-    onepdfdir=os.path.join(outdir,'1Dpdf')
-    if not os.path.isdir(onepdfdir):
-        os.makedirs(onepdfdir)
-
-    sampsdir=os.path.join(outdir,'1Dsamps')
-    if not os.path.isdir(sampsdir):
-        os.makedirs(sampsdir)
-    Nskip=0
-    if 'chain' in pos.names:
-        data,header=pos.samples()
-        par_index=pos.names.index('cycle')
-        chain_index=pos.names.index("chain")
-        chains=unique(pos["chain"].samples)
-        chainCycles = [sort(data[ data[:,chain_index] == chain, par_index ]) for chain in chains]
-        chainNcycles = [cycles[-1]-cycles[0] for cycles in chainCycles]
-        chainNskips = [cycles[1] - cycles[0] for cycles in chainCycles]
-    elif 'cycle' in pos.names:
-        cycles = sort(pos['cycle'].samples)
-        Ncycles = cycles[-1]-cycles[0]
-        Nskip = cycles[1]-cycles[0]
-    
+    #Generate new BCI html table row
     printed=0
     for par_name in oneDMenu:
-        par_name=par_name.lower()
-        try:
-            pos[par_name.lower()]
-        except KeyError:
-            #print "No input chain for %s, skipping binning."%par_name
-            continue
-        try:
-            par_bin=GreedyRes[par_name]
-        except KeyError:
-            print "Bin size is not set for %s, skipping binning."%par_name
-            continue
-
-        #print "Binning %s to determine confidence levels ..."%par_name
-        binParams={par_name:par_bin}
-        injection_area=None
-        injection_area=None
-        if greedy:
-          if printed==0:
-            print "Using greedy 1-d binning credible regions\n"
-            printed=1
-          toppoints,injectionconfidence,reses,injection_area,cl_intervals=bppu.greedy_bin_one_param(pos,binParams,confidence_levels)
-        else:
-          if printed==0:
-            print "Using 2-step KDE 1-d credible regions\n"
-            printed=1
-          if pos[par_name].injval is None:
-            injCoords=None
-          else:
-            injCoords=[pos[par_name].injval]
-          _,reses,injstats=bppu.kdtree_bin2Step(pos,[par_name],confidence_levels,injCoords=injCoords)
-          if injstats is not None:
-            injectionconfidence=injstats[3]
-            injection_area=injstats[4]
-             
-        #oneDContCL,oneDContInj = bppu.contigious_interval_one_param(pos,binParams,confidence_levels)
-
-        #Generate new BCI html table row
-        BCItableline='<tr><td>%s</td>'%(par_name)
-        clasciiout+="%s\t"%par_name
-        cls=reses.keys()
-        cls.sort()
-
-        for cl in cls:
-            BCItableline+='<td>%f</td>'%reses[cl]
-            clasciiout+="%f\t"%reses[cl]
-        if injection is not None:
-            if injectionconfidence is not None and injection_area is not None:
-
-                BCItableline+='<td>%f</td>'%injectionconfidence
-                BCItableline+='<td>%f</td>'%injection_area
-                clasciiout+="%f\t"%injectionconfidence
-                clasciiout+="%f"%injection_area
-
-            else:
-                BCItableline+='<td/>'
-                BCItableline+='<td/>'
-                clasciiout+="nan\t"
-                clasciiout+="nan"
-        BCItableline+='</tr>'
-        clasciiout+="\n"
-        #Append new table line to section html
-        html_ogci_write+=BCItableline
-
-        #Generate 1D histogram/kde plots
-        print "Generating 1D plot for %s."%par_name
-
-        #Get analytic description if given
-        pdf=cdf=None
-        if analyticLikelihood:
-            pdf = analyticLikelihood.pdf(par_name)
-            cdf = analyticLikelihood.cdf(par_name)
-
-        oneDPDFParams={par_name:50}
-        try:
-            rbins,plotFig=bppu.plot_one_param_pdf(pos,oneDPDFParams,pdf,cdf,plotkde=False)
-        except:
-            print "Failed to produce plot for %s."%par_name
-            continue
-
-        figname=par_name+'.png'
-        oneDplotPath=os.path.join(onepdfdir,figname)
-        plotFig.savefig(oneDplotPath)
-        if(savepdfs): plotFig.savefig(os.path.join(onepdfdir,par_name+'.pdf'))
-        plt.close(plotFig)
-
-        if rbins:
-            print "r of injected value of %s (bins) = %f"%(par_name, rbins)
-
-        ##Produce plot of raw samples
-        myfig=plt.figure(figsize=(4,3.5),dpi=200)
-        pos_samps=pos[par_name].samples
-        if not ("chain" in pos.names):
-            # If there is not a parameter named "chain" in the
-            # posterior, then just produce a plot of the samples.
-            plt.plot(pos_samps,'k,',linewidth=0.0, markeredgewidth=0,figure=myfig)
-            maxLen=len(pos_samps)
-        else:
-            # If there is a parameter named "chain", then produce a
-            # plot of the various chains in different colors, with
-            # smaller dots.
-            data,header=pos.samples()
-            par_index=pos.names.index(par_name)
-            chain_index=pos.names.index("chain")
-            chains=unique(pos["chain"].samples)
-            chainData=[data[ data[:,chain_index] == chain, par_index ] for chain in chains]
-            chainDataRanges=[range(len(cd)) for cd in chainData]
-            maxLen=max([len(cd) for cd in chainData])
-            for rng, data in zip(chainDataRanges, chainData):
-                plt.plot(rng, data, marker=',',linewidth=0.0, markeredgewidth=0,figure=myfig)
-            plt.title("Gelman-Rubin R = %g"%(pos.gelman_rubin(par_name)))
-
-            #dataPairs=[ [rng, data] for (rng,data) in zip(chainDataRanges, chainData)]
-            #flattenedData=[ item for pair in dataPairs for item in pair ]
-            #maxLen=max([len(data) for data in flattenedData])
-            #plt.plot(array(flattenedData),marker=',',linewidth=0.0,figure=myfig)
-
-
-        injpar=pos[par_name].injval
-
-        if injpar is not None:
-            # Allow injection to be 5% outside the posterior plot
-            minrange=min(pos_samps)-0.05*(max(pos_samps)-min(pos_samps))
-            maxrange=max(pos_samps)+0.05*(max(pos_samps)-min(pos_samps))
-            if minrange<injpar and maxrange>injpar:
-                plt.axhline(injpar, color='r', linestyle='-.',linewidth=4)
-        myfig.savefig(os.path.join(sampsdir,figname.replace('.png','_samps.png')))
-        if(savepdfs): myfig.savefig(os.path.join(sampsdir,figname.replace('.png','_samps.pdf')))
-        plt.close(myfig)
-        acfail=0
-        if not (noacf):
-            acffig=plt.figure(figsize=(4,3.5),dpi=200)
-            if not ("chain" in pos.names):
-                data=pos_samps[:,0]
-                try:
-                    (Neff, acl, acf) = bppu.effectiveSampleSize(data, Nskip)
-                    lines=plt.plot(acf, 'k,', marker=',',linewidth=0.0, markeredgewidth=0, figure=acffig)
-                    # Give ACL info if not already downsampled according to it
-                    if nDownsample is None:
-                        plt.title('Autocorrelation Function')
-                    elif 'cycle' in pos.names:
-                        last_color = lines[-1].get_color()
-                        plt.axvline(acl/Nskip, linestyle='-.', color=last_color)
-                        plt.title('ACL = %i   N = %i'%(acl,Neff))
-                except FloatingPointError:
-                    # Ignore
-                    acfail=1
-                    pass
-            else:
-                try:
-                    acls = []
-                    Nsamps = 0.0;
-                    for rng, data, Nskip, Ncycles in zip(chainDataRanges, chainData, chainNskips, chainNcycles):
-                        (Neff, acl, acf) = bppu.effectiveSampleSize(data, Nskip)
-                        acls.append(acl)
-                        Nsamps += Neff
-                        lines=plt.plot(acf,'k,', marker=',',linewidth=0.0, markeredgewidth=0, figure=acffig)
-                        # Give ACL info if not already downsampled according to it
-                        if nDownsample is not None:
-                            last_color = lines[-1].get_color()
-                            plt.axvline(acl/Nskip, linestyle='-.', color=last_color)
-                    if nDownsample is None:
-                        plt.title('Autocorrelation Function')
+      par_name=par_name.lower()
+      try:
+              pos[par_name.lower()]
+      except KeyError:
+      #print "No input chain for %s, skipping binning."%par_name
+             continue
+      try:
+              par_bin=GreedyRes[par_name]
+      except KeyError:
+              print "Bin size is not set for %s, skipping binning."%par_name
+              continue
+      binParams={par_name:par_bin}
+      injection_area=None
+      if greedy:
+                    if printed==0:
+                        print "Using greedy 1-d binning credible regions\n"
+                        printed=1
+                    toppoints,injectionconfidence,reses,injection_area,cl_intervals=bppu.greedy_bin_one_param(pos,binParams,confidence_levels)
+      else:
+                    if printed==0:
+                        print "Using 2-step KDE 1-d credible regions\n"
+                        printed=1
+                    if pos[par_name].injval is None:
+                        injCoords=None
                     else:
-                        plt.title('ACL = %i  N = %i'%(max(acls),Nsamps))
-                except FloatingPointError:
-                    # Ignore
-                    acfail=1
-                    pass
+                        injCoords=[pos[par_name].injval]
+                    _,reses,injstats=bppu.kdtree_bin2Step(pos,[par_name],confidence_levels,injCoords=injCoords)
+                    if injstats is not None:
+                        injectionconfidence=injstats[3]
+                        injection_area=injstats[4]
 
-            acffig.savefig(os.path.join(sampsdir,figname.replace('.png','_acf.png')))
-            if(savepdfs): acffig.savefig(os.path.join(sampsdir,figname.replace('.png','_acf.pdf')))
-            plt.close(acffig)
+      BCItableline='<tr><td>%s</td>'%(par_name)
+      clasciiout+="%s\t"%par_name
+      cls=reses.keys()
+      cls.sort()
 
-        if not noacf:
-	  if not acfail:
-	    acfhtml='<td width="30%"><img width="100%" src="1Dsamps/'+figname.replace('.png', '_acf.png')+'"/></td>'
-	  else:
-	    acfhtml='<td>ACF generation failed!</td>'
-          html_ompdf_write+='<tr><td width="30%"><img width="100%" src="1Dpdf/'+figname+'"/></td><td width="30%"><img width="100%" src="1Dsamps/'+figname.replace('.png','_samps.png')+'"/></td>'+acfhtml+'</tr>'
-        else:
-            html_ompdf_write+='<tr><td width="30%"><img width="100%" src="1Dpdf/'+figname+'"/></td><td width="30%"><img width="100%" src="1Dsamps/'+figname.replace('.png','_samps.png')+'"/></td></tr>'
+      for cl in cls:
+          BCItableline+='<td>%f</td>'%reses[cl]
+          clasciiout+="%f\t"%reses[cl]
+      if injection is not None:
+          if injectionconfidence is not None and injection_area is not None:
 
+              BCItableline+='<td>%f</td>'%injectionconfidence
+              BCItableline+='<td>%f</td>'%injection_area
+              clasciiout+="%f\t"%injectionconfidence
+              clasciiout+="%f"%injection_area
 
-    html_ompdf_write+='</table>'
-    html_ompdf.write(html_ompdf_write)
+          else:
+              BCItableline+='<td/>'
+              BCItableline+='<td/>'
+              clasciiout+="nan\t"
+              clasciiout+="nan"
+      BCItableline+='</tr>'
+      clasciiout+="\n"
+      #Append new table line to section html
+      html_ogci_write+=BCItableline
 
     html_ogci_write+='</table>'
     html_ogci.write(html_ogci_write)
 
-    cornerdir=os.path.join(outdir,'corner')
-    if not os.path.isdir(cornerdir):
-        os.makedirs(cornerdir)
-
     #===============================#
     # Corner plots
     #===============================#
-
-    massParams=['mtotal','m1','m2','mc','m1_source','m2_source','mtotal_source','mc_source']
-    distParams=['distance','distMPC','dist','redshift']
+    cornerdir=os.path.join(outdir,'corner')
+    if not os.path.isdir(cornerdir):
+      os.makedirs(cornerdir)
+    massParams=['mtotal','m1','m2','mc']
+    distParams=['distance','distMPC','dist']
     incParams=['iota','inclination','theta_jn']
     polParams=['psi','polarisation','polarization']
     skyParams=['ra','rightascension','declination','dec']
     timeParams=['time']
-    spinParams=['spin1','spin2','a1','a2','phi1','theta1','phi2','theta2','chi','effectivespin','chi_p','beta','tilt1','tilt2','phi_jl','theta_jn','phi12']
+    spinParams=['spin1','spin2','a1','a2','a1z','a2z','phi1','theta1','phi2','theta2','chi','effectivespin','chi_eff','chi_tot','chi_p','beta','tilt1','tilt2','phi_jl','theta_jn','phi12']
+    sourceParams=['m1_source','m2_source','mtotal_source','mc_source','redshift']
     intrinsicParams=massParams+spinParams
     extrinsicParams=incParams+distParams+polParams+skyParams
+    sourceFrameParams=sourceParams+distParams
     try:
       myfig=bppu.plot_corner(pos,[0.05,0.5,0.95],parnames=intrinsicParams)
     except:
@@ -881,6 +777,17 @@ def cbcBayesPostProc(
       myfig.savefig(os.path.join(cornerdir,'extrinsic.pdf'))
       html_corner+='<tr><td width="100%"><a href="corner/extrinsic.png" target="_blank"><img width="70%" src="corner/extrinsic.png"/></a></td></tr>'
       got_any+=1
+    try:
+      myfig=bppu.plot_corner(pos,[0.05,0.5,0.95],parnames=sourceFrameParams)
+    except:
+      myfig=None
+
+    if myfig:
+      myfig.savefig(os.path.join(cornerdir,'sourceFrame.png'))
+      myfig.savefig(os.path.join(cornerdir,'sourceFrame.pdf'))
+      html_corner+='<tr><td width="100%"><a href="corner/sourceFrame.png" target="_blank"><img width="70%" src="corner/sourceFrame.png"/></a></td></tr>'
+      got_any+=1
+
     if got_any>0:
       html_corner='<table id="%s" border="1">'%tabid+html_corner
       html_corner+='</table>'
@@ -1076,9 +983,12 @@ def cbcBayesPostProc(
                     html_tcmp_write+='</tr>'
                     row_count=0
 
-                myfig.savefig(twoDKdePath)
-                if(savepdfs): myfig.savefig(twoDKdePath.replace('.png','.pdf'))
-                plt.close(myfig)
+                if myfig:
+                  myfig.savefig(twoDKdePath)
+                  if(savepdfs): myfig.savefig(twoDKdePath.replace('.png','.pdf'))
+                  plt.close(myfig)
+                else:
+                  print 'Unable to generate 2D kde levels for %s-%s'%(par1_name,par2_name)
 
 
     #Finish off the BCI table and write it into the etree
@@ -1192,9 +1102,6 @@ def cbcBayesPostProc(
     resultspage=open(os.path.join(outdir,'posplots.html'),'w')
     resultspage.write(str(html))
 
-    # Save posterior samples too...
-    posfilename=os.path.join(outdir,'posterior_samples.dat')
-    pos.write_to_file(posfilename)
 
     #Close files
     resultspage.close()
@@ -1226,7 +1133,7 @@ if __name__=='__main__':
     
     parser.add_option('--ellipticEvidence', action='store_true', default=False,help='Estimate the evidence by fitting ellipse to highest-posterior points.', dest='ellevidence')
 
-    parser.add_option("--no2D",action="store_true",default=False,help="Skip 2-D plotting.")
+    parser.add_option("--plot-2d", action="store_true", default=False,help="Make individual 2-D plots.")
     parser.add_option("--header",action="store",default=None,help="Optional file containing the header line for posterior samples",type="string")
     #NS
     parser.add_option("--ns",action="store_true",default=False,help="(inspnest) Parse input as if it was output from parallel nested sampling runs.")
@@ -1257,6 +1164,7 @@ if __name__=='__main__':
     parser.add_option("--archive",action="store",default=None,type="string",metavar="results.tar.gz",help="Create the given tarball with all results")
     parser.add_option("--psdfiles",action="store",default=None,type="string",metavar="H1,L1,V1",help="comma separater list of ASCII files with PSDs, one per IFO")
     parser.add_option("--kdecredibleregions",action="store_true",default=False,help="If given, will use 2-step KDE trees to estimate 1-d credible regions [default false: use greedy binning]")
+    parser.add_option("--noplot-source-frame", action="store_true", default=False,help="Don't make 1D plots of source-frame masses")
     (opts,args)=parser.parse_args()
 
     datafiles=[]
@@ -1270,32 +1178,29 @@ if __name__=='__main__':
     else:
       fixedBurnins = None
 
-    #List of parameters to plot/bin . Need to match (converted) column names.
-    massParams=['m1','m2','chirpmass','mchirp','mc','eta','q','massratio','asym_massratio','mtotal','m1_source','m2_source','mtotal_source','mc_source']
-    distParams=['distance','distMPC','dist','redshift']
-    incParams=['iota','inclination','cosiota']
-    polParams=['psi','polarisation','polarization']
-    skyParams=['ra','rightascension','declination','dec']
-    timeParams=['time','time_mean']
-    spinParams=['spin1','spin2','a1','a2','phi1','theta1','phi2','theta2','costilt1','costilt2','chi','effectivespin','chi_p','costheta_jn','cosbeta','tilt1','tilt2','phi_jl','theta_jn','phi12']
-    phaseParams=['phase', 'phi0','phase_maxl']
-    endTimeParams=['l1_end_time','h1_end_time','v1_end_time']
-    ppEParams=['ppEalpha','ppElowera','ppEupperA','ppEbeta','ppElowerb','ppEupperB','alphaPPE','aPPE','betaPPE','bPPE']
-    tigerParams=['dphi%i'%(i) for i in range(7)] + ['dphi%il'%(i) for i in [5,6] ]
-    bransDickeParams=['omegaBD','ScalarCharge1','ScalarCharge2']
-    massiveGravitonParams=['lambdaG']
-    tidalParams=['lambda1','lambda2','lam_tilde','dlam_tilde','lambdat','dlambdat']
-    statsParams=['logprior','logl','deltalogl','deltaloglh1','deltalogll1','deltaloglv1','deltaloglh2','deltaloglg1','flow']
-    snrParams=bppu.snrParams
-    oneDMenu=massParams + distParams + incParams + polParams + skyParams + timeParams + spinParams + phaseParams + endTimeParams + ppEParams + tigerParams + bransDickeParams + massiveGravitonParams + tidalParams + statsParams + snrParams
-    # ['mtotal','m1','m2','chirpmass','mchirp','mc','distance','distMPC','dist','iota','inclination','psi','eta','massratio','ra','rightascension','declination','dec','time','a1','a2','phi1','theta1','phi2','theta2','costilt1','costilt2','chi','effectivespin','phase','l1_end_time','h1_end_time','v1_end_time']
+    import pylal 
+    from pylal.bayespputils import massParams,spinParams,cosmoParam,strongFieldParams,distParams,incParams,polParams,skyParams,phaseParams,timeParams,endTimeParams,statsParams,calibParams,snrParams,tidalParams
+
+    oneDMenus={'Masses':None,'SourceFrame':None,'Timing':None,'Extrinsic':None,'Spins':None,'StrongField':None,'Others':None}
+
+    oneDMenus['Masses']= massParams
+    oneDMenus['Extrinsic']=incParams+distParams+polParams+skyParams+phaseParams
+    oneDMenus['Spins']= spinParams
+    oneDMenus['Timing']=timeParams+endTimeParams
+    oneDMenus['StrongField']= strongFieldParams
+    oneDMenus['Others']=snrParams+statsParams+calibParams
+    oneDMenus['SourceFrame']= cosmoParam
+    
+    if opts.noplot_source_frame:
+      oneDMenus['SourceFrame']= []
+
     ifos_menu=['h1','l1','v1']
     from itertools import combinations
     for ifo1,ifo2 in combinations(ifos_menu,2):
-      oneDMenu.append(ifo1+ifo2+'_delay')
+      oneDMenus['Timing'].append(ifo1+ifo2+'_delay')
     #oneDMenu=[]
     twoDGreedyMenu=[]
-    if not opts.no2D:
+    if opts.plot_2d:
         for mp1,mp2 in combinations(massParams,2):
           twoDGreedyMenu.append([mp1, mp2])
         for mp in massParams:
@@ -1304,6 +1209,9 @@ if __name__=='__main__':
         for mp in massParams:
             for sp in spinParams:
                 twoDGreedyMenu.append([mp,sp])
+        for mp in massParams:
+            for dchi in bppu.tigerParams:
+                twoDGreedyMenu.append([mp,dchi])
         for dp in distParams:
             for sp in snrParams:
                 twoDGreedyMenu.append([dp,sp])
@@ -1332,6 +1240,8 @@ if __name__=='__main__':
                     twoDGreedyMenu.append([sp1, sp2])
         for sp1,sp2 in combinations(spinParams,2):
           twoDGreedyMenu.append([sp1, sp2])
+        for dc1,dc2 in combinations(bppu.tigerParams,2):
+            twoDGreedyMenu.append([dc1,dc2])
         for mp in massParams:
              for tp in tidalParams:
                  if not (mp == tp):
@@ -1349,31 +1259,26 @@ if __name__=='__main__':
             for sp in spinParams:
                 twoDGreedyMenu.append([psip,sp])
 
+        for i in calibParams[3:]:
+          twoDGreedyMenu.append([i,'distance'])
+
     #twoDGreedyMenu=[['mc','eta'],['mchirp','eta'],['m1','m2'],['mtotal','eta'],['distance','iota'],['dist','iota'],['dist','m1'],['ra','dec']]
     #Bin size/resolution for binning. Need to match (converted) column names.
-    greedyBinSizes={'mc':0.025,'m1':0.1,'m2':0.1,'mass1':0.1,'mass2':0.1,'mtotal':0.1,'mc_source':0.025,'m1_source':0.1,'m2_source':0.1,'mtotal_source':0.1,'eta':0.001,'q':0.01,'asym_massratio':0.01,'iota':0.01,'cosiota':0.02,'time':1e-4,'time_mean':1e-4,'distance':1.0,'dist':1.0,'redshift':0.01,'mchirp':0.025,'chirpmass':0.025,'spin1':0.04,'spin2':0.04,'a1':0.02,'a2':0.02,'phi1':0.05,'phi2':0.05,'theta1':0.05,'theta2':0.05,'ra':0.05,'dec':0.05,'chi':0.05,'chi_eff':0.05,'chi_tot':0.05,'chi_p':0.05,'costilt1':0.02,'costilt2':0.02,'thatas':0.05,'costheta_jn':0.02,'beta':0.05,'omega':0.05,'cosbeta':0.02,'ppealpha':1.0,'ppebeta':1.0,'ppelowera':0.01,'ppelowerb':0.01,'ppeuppera':0.01,'ppeupperb':0.01,'polarisation':0.04,'rightascension':0.05,'declination':0.05,'massratio':0.001,'inclination':0.01,'phase':0.05,'tilt1':0.05,'tilt2':0.05,'phi_jl':0.05,'theta_jn':0.05,'phi12':0.05,'flow':1.0,'phase_maxl':0.05}
-    for s in snrParams:
-            greedyBinSizes[s]=0.05
-    for derived_time in ['h1_end_time','l1_end_time','v1_end_time','h1l1_delay','l1v1_delay','h1v1_delay']:
-        greedyBinSizes[derived_time]=greedyBinSizes['time']
-    if not opts.no2D:
+    greedyBinSizes=bppu.greedyBinSizes
+    
+    
+    if opts.plot_2d:
         for dt1,dt2 in combinations(['h1_end_time','l1_end_time','v1_end_time'],2):
           twoDGreedyMenu.append([dt1,dt2])
         for dt1,dt2 in combinations( ['h1l1_delay','l1v1_delay','h1v1_delay'],2):
           twoDGreedyMenu.append([dt1,dt2])
-    for param in tigerParams + bransDickeParams + massiveGravitonParams:
-        greedyBinSizes[param]=0.01
-    for param in tidalParams:
-        greedyBinSizes[param]=2.5
-    #Confidence levels
-    for loglname in ['logl','deltalogl','deltaloglh1','deltaloglv1','deltalogll1','logll1','loglh1','loglv1']:
-        greedyBinSizes[loglname]=0.1
-    confidenceLevels=[0.67,0.9,0.95,0.99]
+
+    confidenceLevels=bppu.confidenceLevels
     #2D plots list
     #twoDplots=[['mc','eta'],['mchirp','eta'],['mc', 'time'],['mchirp', 'time'],['m1','m2'],['mtotal','eta'],['distance','iota'],['dist','iota'],['RA','dec'],['ra', 'dec'],['m1','dist'],['m2','dist'],['mc', 'dist'],['psi','iota'],['psi','distance'],['psi','dist'],['psi','phi0'], ['a1', 'a2'], ['a1', 'iota'], ['a2', 'iota'],['eta','time'],['ra','iota'],['dec','iota'],['chi','iota'],['chi','mchirp'],['chi','eta'],['chi','distance'],['chi','ra'],['chi','dec'],['chi','psi']]
     twoDplots=twoDGreedyMenu
     cbcBayesPostProc(
-                        opts.outpath,datafiles,oneDMenu,twoDGreedyMenu,
+                        opts.outpath,datafiles,oneDMenus,twoDGreedyMenu,
                         greedyBinSizes,confidenceLevels,twoDplots,
                         #optional
                         injfile=opts.injfile,eventnum=opts.eventnum,
@@ -1426,6 +1331,7 @@ if __name__=='__main__':
     if opts.email:
         try:
             email_notify(opts.email,opts.outpath)
-        except:
+        except Exception,e:
             print 'Unable to send notification email'
+            print "The error was %s\n"%str(e)
 #
