@@ -1,7 +1,7 @@
-id = "fb530cfcc517687cb351bfdd9f4dbcf0ab8d3625"
-date = "2015-10-21 19:51:49 +0000"
+id = "71a71706f9423c2ec61a11b33bf4d2aea30e5153"
+date = "2016-07-06 09:17:25 +0000"
 branch = "master"
-tag = "pylal-v0.9.0-v1"
+tag = "None"
 if tag == "None":
     tag = None
 author = "Kipp Cannon <kipp.cannon@ligo.org>"
@@ -10,11 +10,11 @@ committer = "Kipp Cannon <kipp.cannon@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: master
-Tag: pylal-v0.9.0-v1
-Id: fb530cfcc517687cb351bfdd9f4dbcf0ab8d3625
+Tag: None
+Id: 71a71706f9423c2ec61a11b33bf4d2aea30e5153
 
 Builder: Kipp Cannon <kipp.cannon@ligo.org>
-Build date: 2015-10-21 19:53:11 +0000
+Build date: 2016-07-06 09:17:46 +0000
 Repository status: CLEAN: All modifications committed"""
 
 import warnings
@@ -33,9 +33,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError, onmismatch + " is an unrecognized value of onmismatch"
-    if foreign_id == "fb530cfcc517687cb351bfdd9f4dbcf0ab8d3625":
+    if foreign_id == "71a71706f9423c2ec61a11b33bf4d2aea30e5153":
         return
-    msg = "Program id (fb530cfcc517687cb351bfdd9f4dbcf0ab8d3625) does not match given id (%s)." % foreign_id
+    msg = "Program id (71a71706f9423c2ec61a11b33bf4d2aea30e5153) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError, msg
 
