@@ -684,12 +684,7 @@ class VerticalBarHistogram(BasicPlot):
             plot_kwargs.setdefault("color", c)
 
             # make histogram
-            npv = [int(v) for v in numpy.version.version.split('.')]
-            if npv[1] < 3:
-                y, x = numpy.histogram(data_set, bins=bins, normed=normed,\
-                                       new=True)
-            else:
-                y, x = numpy.histogram(data_set, bins=bins, normed=normed)
+            y, x = numpy.histogram(data_set, bins=bins, normed=normed)
             x = x[:-1]
 
             # mask zeros for logy
@@ -798,13 +793,14 @@ class CumulativeHistogramPlot(BasicPlot):
         min_stat, max_stat = determine_common_bin_limits(\
             self.fg_data_sets + self.bg_data_sets)
         bins = numpy.linspace(min_stat, max_stat, num_bins + 1, endpoint=True)
+        bins_bg = numpy.append(bins, float('Inf'))
         dx = bins[1] - bins[0]
 
         # plot foreground
         for data_set, plot_kwargs in \
             itertools.izip(self.fg_data_sets, self.fg_kwarg_sets):
             # make histogram
-            y, x = numpy.histogram(data_set, bins=bins, new=True)
+            y, x = numpy.histogram(data_set, bins=bins)
             y = y[::-1].cumsum()[::-1]
             x = x[:-1]
 
@@ -820,7 +816,8 @@ class CumulativeHistogramPlot(BasicPlot):
             sq_hist_sum = numpy.zeros(len(bins), dtype=float)
             for instance in self.bg_data_sets:
                 # make histogram
-                y, x = numpy.histogram(instance, bins=bins, new=False)
+	        y, x = numpy.histogram(instance, bins=bins_bg)
+                x = numpy.delete(x, -1)
                 y = y[::-1].cumsum()[::-1]
                 hist_sum += y
                 sq_hist_sum += y*y
@@ -1877,12 +1874,7 @@ class LineHistogram(BasicPlot):
             itertools.izip(self.data_sets, self.normalize_values,\
                            self.kwarg_sets):
             # make histogram
-            npv = [int(v) for v in numpy.version.version.split('.')]
-            if npv[1] < 3:
-                y, x = numpy.histogram(data_set, bins=bins, normed=False,\
-                                       new=True)
-            else:
-                y, x = numpy.histogram(data_set, bins=bins, normed=False)
+            y, x = numpy.histogram(data_set, bins=bins, normed=False)
             y = y.astype(float)
             x = x[:-1]
 
